@@ -20,15 +20,15 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#include <Lum/Dlg/ActionDialog.h>
+
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Integer.h>
 #include <Lum/Model/Selection.h>
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
 
-#include <Lum/Dialog.h>
-
-class DiceSetList : public Lum::Dialog
+class DiceSetList : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::SingleLineSelectionRef selection;
@@ -37,10 +37,14 @@ private:
   Lum::Model::ActionRef              editAction;
   Lum::Model::ActionRef              removeAction;
 
+private:
+  void EvaluateRights();
+
 public:
   DiceSetList();
 
-  void PreInit();
+  Lum::Object* GetContent();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
 };
